@@ -1,7 +1,7 @@
 __title__ = 'amazoncaptcha'
-__description__ = "Pure Python, lightweight, Pillow-based solver for Amazon's text captcha."
+__description__ = "Pure Python, lightweight, Pillow-based solver for the Amazon text captcha."
 __url__ = 'https://github.com/a-maliarov/amazoncaptcha'
-__version__ = '0.5.0'
+__version__ = '0.5.1'
 __author__ = 'Anatolii Maliarov'
 __author_email__ = 'tly.mov@gmail.com'
 __license__ = 'MIT'
